==> tds-4.3.13-sources.jar: thredds/server/ncSubset/view/netcdf/CFPointWriterWrapperFactory.java <==
/*
 * Copyright (c) 1998 - 2012. University Corporation for Atmospheric Research/Unidata
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package thredds.server.ncSubset.view.netcdf;

import java.io.IOException;
import java.util.List;

import ucar.nc2.Attribute;
import ucar.nc2.constants.CF;

/**
 * @author mhermida
 *
 */
public final class CFPointWriterWrapperFactory {

	private CFPointWriterWrapperFactory(){}
	
	public static final CFPointWriterWrapper getWriterForFeatureType( CF.FeatureType featureType, String filePath, List<Attribute> atts   ) throws IOException{
		
		if(featureType == CF.FeatureType.timeSeries){		
			return WriterCFStationCollectionWrapper.createWrapper(filePath, atts);
		}
		if (featureType == CF.FeatureType.point ) {
			return WriterCFPointCollectionWrapper.createWrapper(filePath, atts);
		}
		
		if (featureType == CF.FeatureType.profile ) {
			return WriterCFProfileCollectionWrapper.createWrapper(filePath, atts);
		}
		
		throw new UnsupportedOperationException("Unsupported FeatureType: "+featureType.name());
	}
}

==> tds-4.3.14-sources.jar: thredds/server/ncSubset/view/netcdf/CFPointWriterWrapperFactory.java <==
/*
 * Copyright (c) 1998 - 2012. University Corporation for Atmospheric Research/Unidata
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package thredds.server.ncSubset.view.netcdf;

import java.io.IOException;
import java.util.List;

import ucar.nc2.Attribute;
import ucar.nc2.NetcdfFileWriter;
import ucar.nc2.constants.CF;

/**
 * @author mhermida
 *
 */
public final class CFPointWriterWrapperFactory {

	private CFPointWriterWrapperFactory(){}
	
	public static final CFPointWriterWrapper getWriterForFeatureType( NetcdfFileWriter.Version version, CF.FeatureType featureType, String filePath, List<Attribute> atts   ) throws IOException{
		
		if(featureType == CF.FeatureType.timeSeries){		
			return WriterCFStationCollectionWrapper.createWrapper(version, filePath, atts);
		}
		if (featureType == CF.FeatureType.point ) {
			//return WriterCFPointCollectionWrapper.createWrapper(filePath, atts);
			return WriterPointCollectionNoTimeWrapper.createWrapper(version, filePath, atts);
		}
		
		if (featureType == CF.FeatureType.profile ) {
			return WriterCFProfileCollectionWrapper.createWrapper(version, filePath, atts);
		}
		
		if (featureType == CF.FeatureType.timeSeriesProfile ) {
			return WriterCFTimeSeriesProfileCollectionWrapper.createWrapper(version, filePath, atts);
		}		
		
		throw new UnsupportedOperationException("Unsupported FeatureType: "+featureType.name());
	}
}
